
# Changelog
All notable changes to rattail-wave will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.3.3 (2025-09-20)

### Fix

- fix config extension entry point

## v0.3.2 (2024-08-18)

### Fix

- avoid deprecated base class for config extension

## v0.3.1 (2024-07-01)

### Fix

- remove legacy command definitions

## v0.3.0 (2024-06-10)

### Feat

- switch from setup.cfg to pyproject.toml + hatchling

## [0.2.0] - 2024-06-06
### Changed
- Migrate all commands to use `typer`.
- Add alembic scripts to project manifest.

## [0.1.1] - 2024-04-03
### Changed
- Update subcommand entry point group names, per wuttjamaican.

## [0.1.0] - 2023-11-17
### Added
- Initial version.
